LineInfo

Struct LineInfo 

pub struct LineInfo {
    pub byte_len: u64,
}
Metadata for an existing line, including its terminating LF if present.

Fields

byte_len: u64

Number of raw bytes in the line, including its LF if present.

An existing line always contains at least one byte.